@@ -1198,25 +1198,25 @@ class Experimento:
                 if arreglo_grafica_distancias[0] is True:
                     fa.pintar_cilindro(self.objeto_relevante_1[0],
                                        self.objeto_relevante_1[1],
-                                       self.radios_cilindros[i],
+                                       self.radios_volumenes[i],
                                        self.cantidad_posiciones_volumen_1[i],
                                        ax)
                 if arreglo_grafica_distancias[1] is True:
                     fa.pintar_cilindro(self.objeto_relevante_2[0],
                                        self.objeto_relevante_2[1],
-                                       self.radios_cilindros[i],
+                                       self.radios_volumenes[i],
                                        self.cantidad_posiciones_volumen_2[i],
                                        ax)
                 if arreglo_grafica_distancias[2] is True:
                     fa.pintar_cilindro(self.objeto_relevante_3[0],
                                        self.objeto_relevante_3[1],
-                                       self.radios_cilindros[i],
+                                       self.radios_volumenes[i],
                                        self.cantidad_posiciones_volumen_3[i],
                                        ax)
                 if arreglo_grafica_distancias[3] is True:
                     fa.pintar_cilindro(self.objeto_relevante_4[0],
                                        self.objeto_relevante_4[1],
-                                       self.radios_cilindros[i],
+                                       self.radios_volumenes[i],
                                        self.cantidad_posiciones_volumen_4[i],
                                        ax)
             ax.set_xlim(0, 100)
